==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/ManagedPrivateEndpointArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.ManagedPrivateEndpointArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties of a managed private endpoint
 * @property fqdns Fully qualified domain names
 * @property groupId The groupId to which the managed private endpoint is created
 * @property privateLinkResourceId The ARM resource ID of the resource to which the managed private endpoint is created
 */
public data class ManagedPrivateEndpointArgs(
    public val fqdns: Output<List<String>>? = null,
    public val groupId: Output<String>? = null,
    public val privateLinkResourceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.ManagedPrivateEndpointArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.ManagedPrivateEndpointArgs =
        com.pulumi.azurenative.datafactory.inputs.ManagedPrivateEndpointArgs.builder()
            .fqdns(fqdns?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .groupId(groupId?.applyValue({ args0 -> args0 }))
            .privateLinkResourceId(privateLinkResourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ManagedPrivateEndpointArgs].
 */
@PulumiTagMarker
public class ManagedPrivateEndpointArgsBuilder internal constructor() {
    private var fqdns: Output<List<String>>? = null

    private var groupId: Output<String>? = null

    private var privateLinkResourceId: Output<String>? = null

    /**
     * @param value Fully qualified domain names
     */
    @JvmName("uuvmwewqeuyhfvcf")
    public suspend fun fqdns(`value`: Output<List<String>>) {
        this.fqdns = value
    }

    @JvmName("qufmetgtlqpjpkrk")
    public suspend fun fqdns(vararg values: Output<String>) {
        this.fqdns = Output.all(values.asList())
    }

    /**
     * @param values Fully qualified domain names
     */
    @JvmName("ojbdfufjnerfkuvo")
    public suspend fun fqdns(values: List<Output<String>>) {
        this.fqdns = Output.all(values)
    }

    /**
     * @param value The groupId to which the managed private endpoint is created
     */
    @JvmName("rxaqnacyvaawlpnk")
    public suspend fun groupId(`value`: Output<String>) {
        this.groupId = value
    }

    /**
     * @param value The ARM resource ID of the resource to which the managed private endpoint is created
     */
    @JvmName("gvqebsrkccraidxu")
    public suspend fun privateLinkResourceId(`value`: Output<String>) {
        this.privateLinkResourceId = value
    }

    /**
     * @param value Fully qualified domain names
     */
    @JvmName("yiituyabiickhmlv")
    public suspend fun fqdns(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fqdns = mapped
    }

    /**
     * @param values Fully qualified domain names
     */
    @JvmName("ujbpiplexfrbtymb")
    public suspend fun fqdns(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.fqdns = mapped
    }

    /**
     * @param value The groupId to which the managed private endpoint is created
     */
    @JvmName("xmsbodyaafhjkyex")
    public suspend fun groupId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupId = mapped
    }

    /**
     * @param value The ARM resource ID of the resource to which the managed private endpoint is created
     */
    @JvmName("slowertubfhhubfc")
    public suspend fun privateLinkResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateLinkResourceId = mapped
    }

    internal fun build(): ManagedPrivateEndpointArgs = ManagedPrivateEndpointArgs(
        fqdns = fqdns,
        groupId = groupId,
        privateLinkResourceId = privateLinkResourceId,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/ManagedPrivateEndpointArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.ManagedPrivateEndpointArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties of a managed private endpoint
 * @property fqdns Fully qualified domain names
 * @property groupId The groupId to which the managed private endpoint is created
 * @property privateLinkResourceId The ARM resource ID of the resource to which the managed private endpoint is created
 */
public data class ManagedPrivateEndpointArgs(
    public val fqdns: Output<List<String>>? = null,
    public val groupId: Output<String>? = null,
    public val privateLinkResourceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.ManagedPrivateEndpointArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.ManagedPrivateEndpointArgs =
        com.pulumi.azurenative.datafactory.inputs.ManagedPrivateEndpointArgs.builder()
            .fqdns(fqdns?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .groupId(groupId?.applyValue({ args0 -> args0 }))
            .privateLinkResourceId(privateLinkResourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ManagedPrivateEndpointArgs].
 */
@PulumiTagMarker
public class ManagedPrivateEndpointArgsBuilder internal constructor() {
    private var fqdns: Output<List<String>>? = null

    private var groupId: Output<String>? = null

    private var privateLinkResourceId: Output<String>? = null

    /**
     * @param value Fully qualified domain names
     */
    @JvmName("hppxdltcfxkxgsrr")
    public suspend fun fqdns(`value`: Output<List<String>>) {
        this.fqdns = value
    }

    @JvmName("tugjkbuntpcqujkv")
    public suspend fun fqdns(vararg values: Output<String>) {
        this.fqdns = Output.all(values.asList())
    }

    /**
     * @param values Fully qualified domain names
     */
    @JvmName("ynkmikgknbmrikye")
    public suspend fun fqdns(values: List<Output<String>>) {
        this.fqdns = Output.all(values)
    }

    /**
     * @param value The groupId to which the managed private endpoint is created
     */
    @JvmName("uuwexrxdovnikate")
    public suspend fun groupId(`value`: Output<String>) {
        this.groupId = value
    }

    /**
     * @param value The ARM resource ID of the resource to which the managed private endpoint is created
     */
    @JvmName("ytisbrkwcwgtkhsr")
    public suspend fun privateLinkResourceId(`value`: Output<String>) {
        this.privateLinkResourceId = value
    }

    /**
     * @param value Fully qualified domain names
     */
    @JvmName("tprolmprxuhyfxqn")
    public suspend fun fqdns(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fqdns = mapped
    }

    /**
     * @param values Fully qualified domain names
     */
    @JvmName("dbrbveigtiqrvnji")
    public suspend fun fqdns(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.fqdns = mapped
    }

    /**
     * @param value The groupId to which the managed private endpoint is created
     */
    @JvmName("lfeheitvullojpfx")
    public suspend fun groupId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupId = mapped
    }

    /**
     * @param value The ARM resource ID of the resource to which the managed private endpoint is created
     */
    @JvmName("rffelxujiryhpgyg")
    public suspend fun privateLinkResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateLinkResourceId = mapped
    }

    internal fun build(): ManagedPrivateEndpointArgs = ManagedPrivateEndpointArgs(
        fqdns = fqdns,
        groupId = groupId,
        privateLinkResourceId = privateLinkResourceId,
    )
}
